Web servers permitting directory listing are typically used for
sharing files.

Directory listing allows the client to view a simple
list of all the files and folders hosted on the web server. The client
is then able to traverse each directory and download the files.
Cyber-criminals will utilise the presence of directory listing to
discover sensitive files, download protected content, or even just
learn how the web application is structured.

The tool discovered that
the affected page permits directory listing.